pub struct CustomComponentInfo { /* private fields */ }Expand description
Registry of custom Python components, accessible from MCP handlers.
Written by register_custom_component() in the main crate,
read by MCP handlers to identify custom component names and extract fields.
Implementations
Sourceimpl CustomComponentInfo
impl CustomComponentInfo
Sourcepub fn insert(&mut self, id: ComponentId, entry: CustomComponentEntry)
pub fn insert(&mut self, id: ComponentId, entry: CustomComponentEntry)
Register a custom component entry
Sourcepub fn get(&self, id: ComponentId) -> Option<&CustomComponentEntry>
pub fn get(&self, id: ComponentId) -> Option<&CustomComponentEntry>
Look up a custom component by ComponentId
Sourcepub fn iter(&self) -> impl Iterator<Item = (ComponentId, &CustomComponentEntry)>
pub fn iter(&self) -> impl Iterator<Item = (ComponentId, &CustomComponentEntry)>
Iterate over all registered custom components
Sourcepub fn update_type_ptr(
&mut self,
component_id: ComponentId,
new_type_ptr: *const PyTypeObject,
)
pub fn update_type_ptr( &mut self, component_id: ComponentId, new_type_ptr: *const PyTypeObject, )
Update the type_ptr for an existing entry (used during hot reload aliasing). After reload, Python classes get new PyTypeObject pointers; this keeps the entry pointing at the current (live) type object.