pub struct ChildrenBridge;Trait Implementations
Sourceimpl ComponentBridge for ChildrenBridge
impl ComponentBridge for ChildrenBridge
Sourcefn bevy_type_id(&self) -> TypeId
fn bevy_type_id(&self) -> TypeId
Rust TypeId of the Bevy component
Sourcefn py_type_ptr(&self) -> *const PyTypeObject
fn py_type_ptr(&self) -> *const PyTypeObject
Python type object pointer for type matching Read more
Sourcefn register(&self, world: &mut World) -> ComponentId
fn register(&self, world: &mut World) -> ComponentId
Register component with Bevy world and return its ComponentId
Sourcefn extract(
&self,
entity: &mut FilteredEntityMut<'_, '_>,
component_id: ComponentId,
_validity: ValidityFlagWithMode,
py: Python<'_>,
) -> PyResult<Py<PyAny>>
fn extract( &self, entity: &mut FilteredEntityMut<'_, '_>, component_id: ComponentId, _validity: ValidityFlagWithMode, py: Python<'_>, ) -> PyResult<Py<PyAny>>
Extract component from entity and return as Python object Read more
Sourcefn insert(
&self,
_world: &mut World,
_entity: Entity,
_component: &Bound<'_, PyAny>,
) -> PyResult<()>
fn insert( &self, _world: &mut World, _entity: Entity, _component: &Bound<'_, PyAny>, ) -> PyResult<()>
Insert component into entity via world access Read more
Sourcefn insert_into_entity(
&self,
_entity: &mut EntityWorldMut<'_>,
_component: &Bound<'_, PyAny>,
) -> PyResult<()>
fn insert_into_entity( &self, _entity: &mut EntityWorldMut<'_>, _component: &Bound<'_, PyAny>, ) -> PyResult<()>
Insert component directly into an EntityWorldMut Read more
Sourcefn extract_fn(&self) -> ExtractFn
fn extract_fn(&self) -> ExtractFn
Get a function pointer for component extraction. Read more
Sourcefn entity_contains(&self, entity: &EntityRef<'_>) -> bool
fn entity_contains(&self, entity: &EntityRef<'_>) -> bool
Check if entity has this component type
Sourcefn extract_from_entity_ref(
&self,
entity: &EntityRef<'_>,
_validity: ValidityFlagWithMode,
py: Python<'_>,
) -> PyResult<Option<Py<PyAny>>>
fn extract_from_entity_ref( &self, entity: &EntityRef<'_>, _validity: ValidityFlagWithMode, py: Python<'_>, ) -> PyResult<Option<Py<PyAny>>>
Extract component from an EntityRef (read-only access) Read more
Sourcefn extract_from_entity_mut(
&self,
entity: &mut EntityWorldMut<'_>,
_validity: ValidityFlagWithMode,
py: Python<'_>,
) -> PyResult<Option<Py<PyAny>>>
fn extract_from_entity_mut( &self, entity: &mut EntityWorldMut<'_>, _validity: ValidityFlagWithMode, py: Python<'_>, ) -> PyResult<Option<Py<PyAny>>>
Extract component from an EntityWorldMut (mutable access) Read more
Sourcefn insert_bulk_uniform(
&self,
component: &Bound<'_, PyAny>,
entities: &[Entity],
world: &mut World,
) -> PyResult<()>
fn insert_bulk_uniform( &self, component: &Bound<'_, PyAny>, entities: &[Entity], world: &mut World, ) -> PyResult<()>
Insert the same component into multiple entities (bulk uniform spawn). Read more
Sourcefn view_bridge(&self) -> Option<ViewBridge>
fn view_bridge(&self) -> Option<ViewBridge>
Get View API bridge for this component (optional) Read more