pub struct FieldStorage<T>where
T: Clone,{
pub inner: FieldStorageInner<T>,
}Expand description
Generic storage for PyBevy field types (non-Copy types like TextureAtlas)
Supports two modes:
Owned: Python-created value, stored in BoxBorrowed: Reference to field in a component (e.g., sprite.texture_atlas)
Type Parameters
T: The field type (does not need to implementCopy)
Safety
Borrowed variant contains a raw pointer to value data in a component.
The ValidityFlagWithMode ensures this pointer is only dereferenced during
system execution when the pointer is guaranteed to be valid.
Fields
inner: FieldStorageInner<T>Implementations
Sourceimpl<T> FieldStorage<T>where
T: Clone,
impl<T> FieldStorage<T>where
T: Clone,
Sourcepub fn owned(value: T) -> FieldStorage<T>
pub fn owned(value: T) -> FieldStorage<T>
Create owned field storage with validity tracking
Sourcepub fn as_ref(&self) -> Result<&T, StorageError>
pub fn as_ref(&self) -> Result<&T, StorageError>
Get immutable reference to the value, checking validity
Sourcepub fn as_mut(&mut self) -> Result<&mut T, StorageError>
pub fn as_mut(&mut self) -> Result<&mut T, StorageError>
Get mutable reference to the value, checking validity and write permission
Sourcepub fn get(&self) -> Result<T, StorageError>
pub fn get(&self) -> Result<T, StorageError>
Get the current value (returns a clone)
Sourcepub fn borrow_field<F, S>(
&self,
field_accessor: impl Fn(&T) -> &F,
) -> Result<S, StorageError>where
F: Clone,
S: BorrowableStorage<F>,
pub fn borrow_field<F, S>(
&self,
field_accessor: impl Fn(&T) -> &F,
) -> Result<S, StorageError>where
F: Clone,
S: BorrowableStorage<F>,
Borrow a field from the stored value
Returns a borrowed reference to a nested field that can be mutated and have changes persist back to the original storage.
Example
Prefer using borrow_field_as for simpler syntax:
#[getter]
pub fn physical_position(&self) -> PyResult<PyUVec2> {
self.storage.borrow_field_as(|v| &v.physical_position)
}Or use borrow_field directly when more control is needed:
let storage = self.storage.borrow_field(|v| &v.physical_position)?;
Ok(PyUVec2::from_borrowed(storage))Sourcepub fn borrow_field_as<F, S, W>(
&self,
field_accessor: impl Fn(&T) -> &F,
) -> Result<W, StorageError>
pub fn borrow_field_as<F, S, W>( &self, field_accessor: impl Fn(&T) -> &F, ) -> Result<W, StorageError>