pub struct ListStorage<T>where
T: Clone,{ /* private fields */ }Expand description
Generic storage for Vec
Supports two modes:
Owned: Python-created Vec, stored in BoxBorrowed: Reference to Vec field in a component
Implementations
Sourceimpl<T> ListStorage<T>where
T: Clone,
impl<T> ListStorage<T>where
T: Clone,
Sourcepub fn owned(vec: Vec<T>) -> ListStorage<T>
pub fn owned(vec: Vec<T>) -> ListStorage<T>
Create owned list storage
Sourcepub unsafe fn borrowed(
ptr: *mut Vec<T>,
validity: ValidityFlagWithMode,
) -> ListStorage<T>
pub unsafe fn borrowed( ptr: *mut Vec<T>, validity: ValidityFlagWithMode, ) -> ListStorage<T>
Create borrowed list storage with direct pointer to Vec
Safety
ptrmust point to a validVec<T>in a component field- The pointer must remain valid while
validityflag is true
Sourcepub fn as_ref(&self) -> Result<&Vec<T>, StorageError>
pub fn as_ref(&self) -> Result<&Vec<T>, StorageError>
Get immutable reference to the Vec, checking validity
Sourcepub fn as_mut(&mut self) -> Result<&mut Vec<T>, StorageError>
pub fn as_mut(&mut self) -> Result<&mut Vec<T>, StorageError>
Get mutable reference to the Vec, checking validity and write permission
Sourcepub fn get(&self) -> Result<Vec<T>, StorageError>
pub fn get(&self) -> Result<Vec<T>, StorageError>
Get a clone of the Vec
Sourcepub fn len(&self) -> Result<usize, StorageError>
pub fn len(&self) -> Result<usize, StorageError>
Get length of the Vec
Sourcepub fn is_empty(&self) -> Result<bool, StorageError>
pub fn is_empty(&self) -> Result<bool, StorageError>
Check if Vec is empty